==> org.eclipse.passage.lic.jface.source_0.4.0.v20190403-1234.jar: org/eclipse/passage/lic/jface/dialogs/LicensingPages.java <==
/*******************************************************************************
 * Copyright (c) 2018-2019 ArSysOp
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     ArSysOp - initial API and implementation
 *******************************************************************************/
package org.eclipse.passage.lic.jface.dialogs;

import org.eclipse.passage.lic.equinox.LicensingEquinox;
import org.eclipse.passage.lic.internal.jface.dialogs.BasePageRegistry;
import org.eclipse.passage.lic.internal.jface.dialogs.ConditionTypePage;
import org.eclipse.passage.lic.internal.jface.dialogs.RestrictionLevelPage;

public class LicensingPages {

	private static final LicensingPages INSTANCE = new LicensingPages();

	private final LicensingPageRegistry pageRegistry;

	private LicensingPages() {
		LicensingPageRegistry registry = LicensingEquinox.getLicensingService(LicensingPageRegistry.class);
		if (registry == null) {
			registry = createDefaultContributor();
		}
		pageRegistry = registry;
	}

	private BasePageRegistry createDefaultContributor() {
		BasePageRegistry basePageRegistry = new BasePageRegistry();
		// not ready yet
//		basePageRegistry.registerPageContributor(ConditionLocationPage.class, "License Locations");
		basePageRegistry.registerPageContributor(ConditionTypePage.class, "Condition Types");
		basePageRegistry.registerPageContributor(RestrictionLevelPage.class, "Restriction Levels");
		return basePageRegistry;
	}

	public static Iterable<LicensingPageContributor<?>> getPageContributors() {
		return INSTANCE.pageRegistry.getPageContributors();
	}

}

==> org.eclipse.passage.lic.jface.source_0.5.0.v20190617-0717.jar: org/eclipse/passage/lic/jface/dialogs/LicensingPages.java <==
/*******************************************************************************
 * Copyright (c) 2018-2019 ArSysOp
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     ArSysOp - initial API and implementation
 *******************************************************************************/
package org.eclipse.passage.lic.jface.dialogs;

import org.eclipse.passage.lic.equinox.LicensingEquinox;
import org.eclipse.passage.lic.internal.jface.dialogs.BasePageRegistry;
import org.eclipse.passage.lic.internal.jface.dialogs.ConditionLocationPage;
import org.eclipse.passage.lic.internal.jface.dialogs.ConditionTypePage;
import org.eclipse.passage.lic.internal.jface.dialogs.RestrictionLevelPage;
import org.eclipse.passage.lic.internal.jface.i18n.JFaceMessages;

public class LicensingPages {

	private static final LicensingPages INSTANCE = new LicensingPages();

	private final LicensingPageRegistry pageRegistry;

	private LicensingPages() {
		LicensingPageRegistry registry = LicensingEquinox.getLicensingService(LicensingPageRegistry.class);
		if (registry == null) {
			registry = createDefaultContributor();
		}
		pageRegistry = registry;
	}

	private BasePageRegistry createDefaultContributor() {
		BasePageRegistry basePageRegistry = new BasePageRegistry();
		basePageRegistry.registerPageContributor(ConditionLocationPage.class, JFaceMessages.LicensingPages_page_locations);
		basePageRegistry.registerPageContributor(ConditionTypePage.class, JFaceMessages.LicensingPages_page_conditions);
		basePageRegistry.registerPageContributor(RestrictionLevelPage.class, JFaceMessages.LicensingPages_page_restrictions);
		return basePageRegistry;
	}

	public static Iterable<LicensingPageContributor> getPageContributors() {
		return INSTANCE.pageRegistry.getPageContributors();
	}

}
